summaryrefslogtreecommitdiff
path: root/service/static
diff options
context:
space:
mode:
authorWolfy-J <[email protected]>2018-06-13 14:07:05 +0300
committerWolfy-J <[email protected]>2018-06-13 14:07:05 +0300
commitca95f67317bcf8972b9e669869338a7dc09bf06d (patch)
tree4d199ceb8a78675242fef21bd87efb5a78b04029 /service/static
parentc8e8afe79611941ce50453ee7dfae82d7915e9c4 (diff)
more upload tests
Diffstat (limited to 'service/static')
-rw-r--r--service/static/service.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/service/static/service.go b/service/static/service.go
index 5c3defe6..5f7d31f0 100644
--- a/service/static/service.go
+++ b/service/static/service.go
@@ -20,9 +20,9 @@ type Service struct {
root http.Dir
}
// Configure must return configure service and return true if service hasStatus enabled. Must return error in case of
// misconfiguration. Services must not be used without proper configuration pushed first.
-func (s *Service) Configure(cfg service.Config, c service.Container) (enabled bool, err error) {
+func (s *Service) Init(cfg service.Config, c service.Container) (enabled bool, err error) {
config := &Config{}
if err := cfg.Unmarshal(config); err != nil {
return false, err
@@ -20,9 +20,9 @@ type Service struct {
root http.Dir
}
-// Configure must return configure service and return true if service hasStatus enabled. Must return error in case of
+// Init must return configure service and return true if service hasStatus enabled. Must return error in case of
// misconfiguration. Services must not be used without proper configuration pushed first.